import { parser } from 'lezer-jmespath';
import { LRLanguage, indentNodeProp, continuedIndent, foldNodeProp, foldInside, LanguageSupport } from '@codemirror/language';

/**
A language provider that provides jmespath parsing.
*/
const jmespathLanguage = /*@__PURE__*/LRLanguage.define({
    name: "jmespath",
    parser: /*@__PURE__*/parser.configure({
        props: [
            /*@__PURE__*/indentNodeProp.add({
                MultiSelectHash: /*@__PURE__*/continuedIndent({ except: /^\s*\}/ }),
                MultiSelectList: /*@__PURE__*/continuedIndent({ except: /^\s*\]/ })
            }),
            /*@__PURE__*/foldNodeProp.add({
                "MultiSelectHash MultiSelectList": foldInside
            })
        ]
    }),
    languageData: {
        closeBrackets: { brackets: ["[", "{", '"'] },
        indentOnInput: /^\s*[\}\]]$/
    }
});
/**
jmespath language support.
*/
function jmespath() {
    return new LanguageSupport(jmespathLanguage);
}

export { jmespath, jmespathLanguage };
